/////////////////////////////////////////////////////////////////////////////////////////
///
///	\file	Material.h
/// \author	Rob Bateman
/// \brief	This file defines the single function OutputMaterials which will output all
///			of the material information for phong,lambert and blinn shaders to the
///			output files. 
/// \note       
/// 
/// 		This sourcefile is provided as-is and no guarentee or warrenty 
///			is provided for any damage that may arise from using it. This
///			code is free for your own use, the only thing i ask is a small
///			credit somewhere for my work. An e-mail saying you found it 
///			useful would also be much appreciated by myself ;)
///
///			If you find any bugs arising to maya version changes or you
///			have improvements to the source code, then feel free to mail
///			them to me and i'll update the source-code on the website.
///			Before you e-mail bug reports, make sure that it is my code 
///			causing the problem, and not some wierd oddity in the maya 
///			scene. This code is designed to handle most common model set-ups,
///			it is not designed to replicate perfectly everything that maya
///			does. 
/// 
///			DO NOT send me feature requests, i'm not likely to add to this
///			code myself unless something really new and groovy comes along.
///			This is mainly due to my current time restrictions. If you do
///			have code written that adds something fairly groovy to the 
///			exporter, then i will happily update the exporter code and give
///			full credit where due.....
/// 
///			Robert Bateman
/// 
///				email code to:    rbateman@bmth.ac.uk
///				contact:          robthebloke@hotmail.com
///	
//--------------------------------------------------------------------------


#ifdef WIN32
#pragma once
#endif
#ifndef MATERIALS_H_INCLUDED
#define MATERIALS_H_INCLUDED

#include <iostream>
#include <maya/MString.h>


/// \brief	This function outputs all of the material information in the scene
///			to the specified file stream.
/// \param	ofs	-	the output file stream
///
extern void OutputMaterials(std::ostream &ofs);

/// \brief	The materials are assigned a unique ID which is used to reference the
///			material that is used. This function will either returns a previously 
///			used ID or will generate a new ID if a new material is encountered.
///	\param	material	-	the name of the material to output 
/// \return	the ID number of the material.
/// 
extern unsigned int GetMaterialID(const MString &material);

#endif
