//--------------------------------------------------------------------------
///
///	\file	Mesh.h
/// \author	Rob Bateman
/// \brief	This file defines the single function OutputMesh which will write 
///			the mesh data to the file. 
/// \note	It may seem odd that I don't define any structures to hold the mesh 
///			data. For example you may be thinking about traversing the scene 
///			and then building up lists of all the scene data before writing the 
///			whole lot to a file at the end. I would strongly advise against 
///			this apporach. Maya is not a trivial application  and memory usage 
///			from just loading say a large file can be excessive. Maya also
///			tends to have problems when memory is severly restricted, ie - 
///			it crashes.  Because of this, all of my exporters try to export 
///			the data in a way that requires no data to be created.
/// 
/// 
/// 		This sourcefile is provided as-is and no guarentee or warrenty 
///			is provided for any damage that may arise from using it. This
///			code is free for your own use, the only thing i ask is a small
///			credit somewhere for my work. An e-mail saying you found it 
///			useful would also be much appreciated by myself ;)
///
///			If you find any bugs arising to maya version changes or you
///			have improvements to the source code, then feel free to mail
///			them to me and i'll update the source-code on the website.
///			Before you e-mail bug reports, make sure that it is my code 
///			causing the problem, and not some wierd oddity in the maya 
///			scene. This code is designed to handle most common model set-ups,
///			it is not designed to replicate perfectly everything that maya
///			does. 
/// 
///			DO NOT send me feature requests, i'm not likely to add to this
///			code myself unless something really new and groovy comes along.
///			This is mainly due to my current time restrictions. If you do
///			have code written that adds something fairly groovy to the 
///			exporter, then i will happily update the exporter code and give
///			full credit where due.....
/// 
///			Robert Bateman
/// 
///				email code to:    rbateman@bmth.ac.uk
///				contact:          robthebloke@hotmail.com
///	
//--------------------------------------------------------------------------


#ifdef WIN32
#pragma once
#endif

#ifndef MESH_H_INCLUDED
#define MESH_H_INCLUDED

//--------------------------------------------------------------------------
/// the includes
/// 
#include <maya/MObject.h>
#include <maya/MMatrix.h>


//--------------------------------------------------------------------------
/// this function outputs the specified mesh list
/// 
extern void OutputMesh(std::ofstream&,const MObject&);

//--------------------------------------------------------------------------
/// \brief	This function recursively ascends the hierarchy to build the 
///			parent transformation matrix of any shapes we export.
/// 
extern MMatrix BuildTransform(const MObject& obj);


#endif

