///-----------------------------------------------------------------------------
/// 
/// \file	Light.h
/// \author	Rob Bateman
/// \brief	This file defines the class XLight whixh is used to hold information
///			about a light. 
/// \note       
/// 
/// 		This sourcefile is provided as-is and no guarentee or warrenty 
///			is provided for any damage that may arise from using it. This
///			code is free for your own use, the only thing i ask is a small
///			credit somewhere for my work. An e-mail saying you found it 
///			useful would also be much appreciated by myself ;)
///
///			If you find any bugs arising to maya version changes or you
///			have improvements to the source code, then feel free to mail
///			them to me and i'll update the source-code on the website.
///			Before you e-mail bug reports, make sure that it is my code 
///			causing the problem, and not some wierd oddity in the maya 
///			scene. This code is designed to handle most common model set-ups,
///			it is not designed to replicate perfectly everything that maya
///			does. 
/// 
///			DO NOT send me feature requests, i'm not likely to add to this
///			code myself unless something really new and groovy comes along.
///			This is mainly due to my current time restrictions. If you do
///			have code written that adds something fairly groovy to the 
///			exporter, then i will happily update the exporter code and give
///			full credit where due.....
/// 
///			Robert Bateman
/// 
///				email code to:    rbateman@bmth.ac.uk
///				contact:          robthebloke@hotmail.com
///	
//--------------------------------------------------------------------------

#include "Light.h"
#ifdef WIN32
#define WIN32_LEAN_AND_MEAN
#include <Windows.h>
#endif
#include <GL/gl.h>

//--------------------------------------------------------------------------
XLight::XLight(unsigned int id)
	: m_LightNum(id)
{
	m_Color[0] = 0;
	m_Color[1] = 0;
	m_Color[2] = 0;
	m_Color[3] = 0;
	m_Position[0] = 0;
	m_Position[1] = 0;
	m_Position[2] = 0;
	m_Position[3] = 1;
}
//--------------------------------------------------------------------------
XLight::~XLight(void)
{
}
//--------------------------------------------------------------------------
/// this function draws the mesh data
void XLight::Enable()
{
	glPushMatrix();

	/// set the diffuse colour
	glLightfv(GL_LIGHT0 + m_LightNum,GL_DIFFUSE,m_Color);
	
	/// set the lights position
	glLightfv(GL_LIGHT0 + m_LightNum,GL_POSITION,m_Position);

	/// enable the light
	glEnable(GL_LIGHT0 + m_LightNum);

	glPopMatrix();
}
//--------------------------------------------------------------------------
/// this function draws the mesh data
void XLight::Disable()
{
	glDisable(GL_LIGHT0 + m_LightNum);
}

//--------------------------------------------------------------------------
std::istream &operator>>(std::istream& ifs,XLight& l) {
	char buffer[64];
	ifs >> buffer; // name
	ifs >> buffer; // "Type="
	ifs >> buffer; // kPointLight, kAmbientLight, kSpotLight etc
	ifs >> buffer; // "Color="

	ifs >> l.m_Color[0] >> l.m_Color[1] >> l.m_Color[2];

	ifs >> buffer; // "Intensity="

	ifs >> l.m_fIntensity;

	ifs >> buffer; // "Position="
	
	ifs >> l.m_Position[0] >> l.m_Position[1] >> l.m_Position[2];

	return ifs;
}
