///-----------------------------------------------------------------------------
/// 
/// \file	Material.cpp
/// \author	Rob Bateman
/// \brief	I've tried to make this loader a bit more generic. The material 
///			class is now able to store colour channels, ie a colour and a texture
///			for ambient, diffuse, specular etc. With basic openGL this isn't of 
///			much use because you can only use 1 texture 
///			(though 2 with mutlitexturing extension). This is mainly done for my
///			own purposes cos I use CG shaders so a bit more flexibility is nice.
/// 
///			At the moment, if a texture is assigned to the diffuse channel, then 
///			it is used as the surface texture.
/// \note       
/// 
/// 		This sourcefile is provided as-is and no guarentee or warrenty 
///			is provided for any damage that may arise from using it. This
///			code is free for your own use, the only thing i ask is a small
///			credit somewhere for my work. An e-mail saying you found it 
///			useful would also be much appreciated by myself ;)
///
///			If you find any bugs arising to maya version changes or you
///			have improvements to the source code, then feel free to mail
///			them to me and i'll update the source-code on the website.
///			Before you e-mail bug reports, make sure that it is my code 
///			causing the problem, and not some wierd oddity in the maya 
///			scene. This code is designed to handle most common model set-ups,
///			it is not designed to replicate perfectly everything that maya
///			does. 
/// 
///			DO NOT send me feature requests, i'm not likely to add to this
///			code myself unless something really new and groovy comes along.
///			This is mainly due to my current time restrictions. If you do
///			have code written that adds something fairly groovy to the 
///			exporter, then i will happily update the exporter code and give
///			full credit where due.....
/// 
///			Robert Bateman
/// 
///				email code to:    rbateman@bmth.ac.uk
///				contact:          robthebloke@hotmail.com
///	
//--------------------------------------------------------------------------

#include "Material.h"
#ifdef WIN32
#define WIN32_LEAN_AND_MEAN
#include <Windows.h>
#endif
#include <GL/gl.h>
//--------------------------------------------------------------------------
XMaterial::XMaterial(void)
{
}
//--------------------------------------------------------------------------
XMaterial::~XMaterial(void)
{
}
//--------------------------------------------------------------------------
/// as an optimisation, we will track which material is currently in use. This will 
/// try to minimise the state changes within OpenGL
XMaterial* XMaterial::ms_CurrentMaterial = NULL;

//--------------------------------------------------------------------------
void XMaterial::gl(){
	// make sure we don't bind the material more than nessecary
	if (this==ms_CurrentMaterial) {
		return;
	}
	ms_CurrentMaterial = this;

	if (m_Diffuse.m_TextureObject!=0) {
		glEnable(GL_TEXTURE_2D);
		glBindTexture(GL_TEXTURE_2D,m_Diffuse.m_TextureObject);
	}
	else {
		glDisable(GL_TEXTURE_2D);
	}

	glMaterialfv(GL_FRONT,GL_AMBIENT,m_Ambient.m_Colour);
	glMaterialfv(GL_FRONT,GL_DIFFUSE,m_Diffuse.m_Colour);
	glMaterialfv(GL_FRONT,GL_SPECULAR,m_Specular.m_Colour);
	glMaterialfv(GL_FRONT,GL_EMISSION,m_Emission.m_Colour);
	glMaterialf(GL_FRONT,GL_SHININESS,m_Shininess);
}

//--------------------------------------------------------------------------
std::istream& operator >> (std::istream& ifs,XPhong& ph)
{
	char buffer[256];

	ifs >> buffer // name
		>> ph.m_Ambient
		>> ph.m_Diffuse
		>> ph.m_Specular
		>> ph.m_Emission
		>> ph.m_Transparency
		>> buffer // shininess
		>> ph.m_Shininess;
		return ifs;
}
//--------------------------------------------------------------------------
std::istream& operator >> (std::istream& ifs,XLambert& ph)
{
	char buffer[256];

	ifs >> buffer // name
		>> ph.m_Ambient
		>> ph.m_Diffuse
		>> ph.m_Emission
		>> ph.m_Transparency;

		return ifs;
}
//--------------------------------------------------------------------------
std::istream& operator >> (std::istream& ifs,XBlinn& ph)
{
	char buffer[256];

	float e;
	float sro;

	ifs >> buffer // name
		>> ph.m_Ambient
		>> ph.m_Diffuse
		>> ph.m_Specular
		>> ph.m_Emission
		>> ph.m_Transparency
		>> buffer // shininess
		>> e
		>> buffer // shininess
		>> sro;

	ph.m_Specular.m_Colour[0] *= sro;
	ph.m_Specular.m_Colour[1] *= sro;
	ph.m_Specular.m_Colour[2] *= sro;
	ph.m_Specular.m_Colour[3] *= sro;

	ph.m_Shininess = (1.0f-e)*100;
	return ifs;
}
