///-----------------------------------------------------------------------------
/// 
/// \file	Model.h
/// \author	Rob Bateman
/// \brief	This file defines the XModel class. basicaly this class will load the 
///			contents of a mod file. This version merely holds lights and 
///			meshes in one place and is responsible for drawing them.
/// \note       
/// 
/// 		This sourcefile is provided as-is and no guarentee or warrenty 
///			is provided for any damage that may arise from using it. This
///			code is free for your own use, the only thing i ask is a small
///			credit somewhere for my work. An e-mail saying you found it 
///			useful would also be much appreciated by myself ;)
///
///			If you find any bugs arising to maya version changes or you
///			have improvements to the source code, then feel free to mail
///			them to me and i'll update the source-code on the website.
///			Before you e-mail bug reports, make sure that it is my code 
///			causing the problem, and not some wierd oddity in the maya 
///			scene. This code is designed to handle most common model set-ups,
///			it is not designed to replicate perfectly everything that maya
///			does. 
/// 
///			DO NOT send me feature requests, i'm not likely to add to this
///			code myself unless something really new and groovy comes along.
///			This is mainly due to my current time restrictions. If you do
///			have code written that adds something fairly groovy to the 
///			exporter, then i will happily update the exporter code and give
///			full credit where due.....
/// 
///			Robert Bateman
/// 
///				email code to:    rbateman@bmth.ac.uk
///				contact:          robthebloke@hotmail.com
///	
//--------------------------------------------------------------------------

//--------------------------------------------------------------------------
/// The XModel class basically holds the contents of a read file. This may
/// contain a number of 

#ifdef WIN32
#pragma once
#endif

//--------------------------------------------------------------------------

#ifndef _X_MODEL__H__
#define _X_MODEL__H__

#include <vector>
#include <list>
#include "./Light.h"
#include "./Material.h"
#include "./Mesh.h"
#include "./TextureFile.h"

//--------------------------------------------------------------------------


/// a list of lights type
typedef std::vector< XLight* > XLightList;

/// an iterator for a light list
typedef XLightList::iterator XItLight;



/// a list of lights type
typedef std::vector< XMesh* > XMeshList;

/// an iterator for a light list
typedef XMeshList::iterator XItMesh;





//--------------------------------------------------------------------------
/// \brief	This class contains all of the data loaded from the exported file
/// 
class XModel
{
public:

	//----------------------------------------------------------------------
	/// ctor
	XModel(void);

	//----------------------------------------------------------------------
	/// dtor
	~XModel(void);

	//----------------------------------------------------------------------
	/// a function to draw the geometry data in the model
	void gl();

	//----------------------------------------------------------------------
	/// a function to load a file into the model
	bool Load(const char* const filename);

	//----------------------------------------------------------------------
	/// is the model textured?
	bool IsTextured() const {
		return m_TextureObject != 0 ;
	}

	//----------------------------------------------------------------------
	/// does the model contain lights?
	bool IsLit() const {
		return m_Lights.size() != 0;
	}

protected:

	//----------------------------------------------------------------------
	/// this Function enables all of the lights in the model
	void EnableLights();

	//----------------------------------------------------------------------
	/// this function disables all of the lights in the model
	void DisableLights();

	/// a texture object for all of the textures in the model
	unsigned int m_TextureObject;

	/// the number of textures in the model
	unsigned int m_NumTextures;

	/// a list of materials
	XMaterialList m_Materials;

	/// a list of lights
	XLightList m_Lights;

	/// a list of meshes
	XMeshList m_Meshes;


};

#endif


