///-----------------------------------------------------------------------------
/// 
/// \file	Texture.cpp
/// \author	Rob Bateman
/// \brief	This file defines the XImageHeader and the XTexture classes. These 
///			are used to read a texture file from a texture file
/// \note       
/// 
/// 		This sourcefile is provided as-is and no guarentee or warrenty 
///			is provided for any damage that may arise from using it. This
///			code is free for your own use, the only thing i ask is a small
///			credit somewhere for my work. An e-mail saying you found it 
///			useful would also be much appreciated by myself ;)
///
///			If you find any bugs arising to maya version changes or you
///			have improvements to the source code, then feel free to mail
///			them to me and i'll update the source-code on the website.
///			Before you e-mail bug reports, make sure that it is my code 
///			causing the problem, and not some wierd oddity in the maya 
///			scene. This code is designed to handle most common model set-ups,
///			it is not designed to replicate perfectly everything that maya
///			does. 
/// 
///			DO NOT send me feature requests, i'm not likely to add to this
///			code myself unless something really new and groovy comes along.
///			This is mainly due to my current time restrictions. If you do
///			have code written that adds something fairly groovy to the 
///			exporter, then i will happily update the exporter code and give
///			full credit where due.....
/// 
///			Robert Bateman
/// 
///				email code to:    rbateman@bmth.ac.uk
///				contact:          robthebloke@hotmail.com
///	
//--------------------------------------------------------------------------

#include "Texture.h"
#include <assert.h>

//--------------------------------------------------------------------------
XTexture::XTexture(void)
{
}

//--------------------------------------------------------------------------
XTexture::~XTexture(void)
{
}

//--------------------------------------------------------------------------
/// this function reads a texture from the specified file pointer
bool XTexture::Read(FILE* fp)
{
	// read the 2 byte image header
	if( 0 != fread(&m_Header,sizeof(XImageHeader),1,fp) )
	{
		// get the size of the pixel data
		unsigned int size = GetWidth()*GetHeight()*GetBytesPerPixel();

		// allocate memory for it
		m_Pixels = new unsigned char [ size ];
		assert(m_Pixels);

		// read the pixel data from the file
		if(0!=fread(m_Pixels,size,1,fp))
			return true;
	}
	return false;
}
