///-----------------------------------------------------------------------------
/// 
/// \file	TextureFile.h
/// \author	Rob Bateman
/// \brief	the XTextureFile class holds a list of all loaded textures from the 
///			specified file.
/// \note       
/// 
/// 		This sourcefile is provided as-is and no guarentee or warrenty 
///			is provided for any damage that may arise from using it. This
///			code is free for your own use, the only thing i ask is a small
///			credit somewhere for my work. An e-mail saying you found it 
///			useful would also be much appreciated by myself ;)
///
///			If you find any bugs arising to maya version changes or you
///			have improvements to the source code, then feel free to mail
///			them to me and i'll update the source-code on the website.
///			Before you e-mail bug reports, make sure that it is my code 
///			causing the problem, and not some wierd oddity in the maya 
///			scene. This code is designed to handle most common model set-ups,
///			it is not designed to replicate perfectly everything that maya
///			does. 
/// 
///			DO NOT send me feature requests, i'm not likely to add to this
///			code myself unless something really new and groovy comes along.
///			This is mainly due to my current time restrictions. If you do
///			have code written that adds something fairly groovy to the 
///			exporter, then i will happily update the exporter code and give
///			full credit where due.....
/// 
///			Robert Bateman
/// 
///				email code to:    rbateman@bmth.ac.uk
///				contact:          robthebloke@hotmail.com
///	
//--------------------------------------------------------------------------


#ifdef WIN32
#pragma once
#endif

#ifndef __X_TEXTURE_FILE__H__
#define __X_TEXTURE_FILE__H__

#include <vector>
#include "Texture.h"

//--------------------------------------------------------------------------
/// \brief	This class holds a set of loaded textures. 
/// 
class XTextureFile 
	: protected std::vector< XTexture* >
{
public:

	//----------------------------------------------------------------------
	/// \brief	ctor
	///
	XTextureFile(void);

	//----------------------------------------------------------------------
	/// \brief	dtor
	/// 
	~XTextureFile(void);

	//----------------------------------------------------------------------
	/// \brief	returns a pointer to the requested texture data
	/// \param	id	-	the id number of the texture
	/// \return	a pointer to the texture
	/// 
	XTexture* GetTexture(unsigned int id) const 
	{
		if(id == 0)
			return NULL;

		if (id-1 < size()) {
			return (*this)[id-1];
		}
		return NULL;
	}

	//----------------------------------------------------------------------
	/// \brief	this function converts all image data into a single openGL 
	///			texture object. to use each texture, use tex_obj + n to get
	///			the n'th texture object
	/// \param	tex_obj	-	the output texture object
	/// \return	true if OK
	///
	bool TurnIntoTextures(unsigned int& tex_obj);

	//----------------------------------------------------------------------
	/// \brief	returns the number of textures in the file
	/// 
	unsigned int GetNumTextures() const {
		return static_cast<unsigned int>(size());
	}

	//----------------------------------------------------------------------
	/// \brief	this function loads the specified file
	/// \param	filename	-	the name of the file to load
	/// \return	true if OK
	/// 
	bool Load(const char* const filename);

};

#endif


