///-----------------------------------------------------------------------------
/// 
/// \file	main.cpp
/// \author	Rob Bateman
/// \brief	
/// \note       
/// 
/// 		This sourcefile is provided as-is and no guarentee or warrenty 
///			is provided for any damage that may arise from using it. This
///			code is free for your own use, the only thing i ask is a small
///			credit somewhere for my work. An e-mail saying you found it 
///			useful would also be much appreciated by myself ;)
///
///			If you find any bugs arising to maya version changes or you
///			have improvements to the source code, then feel free to mail
///			them to me and i'll update the source-code on the website.
///			Before you e-mail bug reports, make sure that it is my code 
///			causing the problem, and not some wierd oddity in the maya 
///			scene. This code is designed to handle most common model set-ups,
///			it is not designed to replicate perfectly everything that maya
///			does. 
/// 
///			DO NOT send me feature requests, i'm not likely to add to this
///			code myself unless something really new and groovy comes along.
///			This is mainly due to my current time restrictions. If you do
///			have code written that adds something fairly groovy to the 
///			exporter, then i will happily update the exporter code and give
///			full credit where due.....
/// 
///			Robert Bateman
/// 
///				email code to:    rbateman@bmth.ac.uk
///				contact:          robthebloke@hotmail.com
///	
//--------------------------------------------------------------------------

#ifdef WIN32
#include<Windows.h>
#endif

#include <GL/glut.h>
#include "Model.h"
#include "FileDialog.h"

//--------------------------------------------------------------------------
XModel model;

float zoom = 15.0f;
float rotx = 0;
float roty = 0.001f;
float tx = 0;
float ty = 0;
int lastx=0;
int lasty=0;
unsigned char Buttons[3] = {0};

//--------------------------------------------------------------------------
void Init() 
{
	glEnable(GL_DEPTH_TEST);
	glEnable(GL_LIGHT0);
	glEnable(GL_LIGHTING);
	glEnable(GL_TEXTURE_2D);
	glTexEnvi(GL_TEXTURE_ENV,GL_TEXTURE_ENV_MODE,GL_MODULATE);
}

//--------------------------------------------------------------------------
void display()
{
	glClear(GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT);
	glLoadIdentity();
	
	glTranslatef(0,0,-zoom);
	glTranslatef(tx,ty,0);
	glRotatef(rotx,1,0,0);
	glRotatef(roty,0,1,0);	

	glPushMatrix();

		model.gl();

	glPopMatrix();

	glutSwapBuffers();
}

//--------------------------------------------------------------------------
void reshape(int x, int y)
{
	if(y==0) y = 1;
	glViewport(0,0,x,y);
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	gluPerspective(45,(float)x/y,0.1,100);
	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();

}

//--------------------------------------------------------------------------
/*! don't really care where or when you call exit, but you will need it somewhere if
 *  you want to get out of fullscreen mode */
void Motion(int x,int y)
{
	int diffx=x-lastx;
	int diffy=y-lasty;
	lastx=x;
	lasty=y;
	
	if( Buttons[0] && Buttons[1] )
	{
		zoom -= (float) 0.05f * diffx;
	}
	else
	if( Buttons[0] )
	{
		rotx += (float) 0.5f * diffy;
		roty += (float) 0.5f * diffx;		
	}
	else
	if( Buttons[1] )
	{
		tx += (float) 0.05f * diffx;
		ty -= (float) 0.05f * diffy;
	}
	glutPostRedisplay();
}
//--------------------------------------------------------------------------
/*! don't really care where or when you call exit, but you will need it somewhere if
 *  you want to get out of fullscreen mode */
void Mouse(int b,int s,int x,int y)
{
	lastx=x;
	lasty=y;
	switch(b)
	{
	case GLUT_LEFT_BUTTON:
			Buttons[0] = ((GLUT_DOWN==s)?1:0);
			break;
	case GLUT_MIDDLE_BUTTON:
			Buttons[1] = ((GLUT_DOWN==s)?1:0);
			break;
	case GLUT_RIGHT_BUTTON:
			Buttons[2] = ((GLUT_DOWN==s)?1:0);
			break;
	default:
		break;		
	}
	glutPostRedisplay();
}

//--------------------------------------------------------------------------
#ifdef WIN32
int main(int argc,char** argv)
{

#else
int g_argc=0;
char** g_argv=0;
int main(int argc,char** argv)
{
	g_argc = argc;
	g_argv = argv;

#endif
	std::string infile;
	if( argc == 2 )
		infile = argv[1];
	else
	{
		char buffer[512] = {0};
		if( !OpenFileDialog(buffer) ) {
			return 0;
		}
		infile = buffer;
	}

	glutInit(&argc,argv);
	glutInitDisplayMode(GLUT_DOUBLE|GLUT_RGBA|GLUT_DEPTH);
	glutInitWindowSize(640,480);
	glutInitWindowPosition(100,100);
	glutCreateWindow("hello");


	glutDisplayFunc(display);
	glutReshapeFunc(reshape);
	glutMouseFunc(Mouse);		/* set the mouse press handler function */
	glutMotionFunc(Motion);		/* set the mouse motion handler */

	Init();

	model.Load(infile.c_str());
	
	glutMainLoop();
}

























