#include "Line.h"


XVector XLine::ClosestPoint(const XVector &p) const {
	// Create the vector from end point Point1 to our point p.
	XVector v1 = p - Point1;
	
	// Create a direction vector from end point Point1 to end point Point2
	XVector v2 = (Point2 - Point1);
	
	// calculate distance between end points
	float d = v2.Length();
	
	// normalise the direction vector
	v2.Normalise();
	
	// Using the dot product, we project the v1 onto the vector v2.
	// This essentially gives us the distance from our projected vector from Point1.
	float t = v2 * v1;
	
	// If our projected distance from Point1, "t", is less than or equal to 0, it must
	// be closest to the end point vA.  We want to return this end point.
	if (t <= 0) 
		return Point1;
	
	// If our projected distance from Point2, "t", is greater than or equal to the magnitude
	// or distance of the line segment, it must be closest to the end point vB.  So, return vB.
	if (t >= d) 
		return Point2;
	
	// Here we create a vector that is of length t and in the direction of vVector2
	XVector v3 = v2 * t;
	
	// adding out direction to the start point gives the closet point
	return Point1 + v3;
}
